@@ -35,7 +35,7 @@ class EasyDict(dict):
             self.pop(arg)
 
     def stay(self, *args):
-        for i in self.keys():
+        for i in list(self.keys()):
             if i not in args:
                 self.pop(i)
 
